==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/DomainChartSeriesPointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { DomainChartSeriesPointerEventArgsDescription } from "./DomainChartSeriesPointerEventArgsDescription";
/**
 * @hidden
 */
export let DomainChartSeriesPointerEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DomainChartSeriesPointerEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DomainChartSeriesPointerEventArgsDescriptionMetadata.a == null) {
                DomainChartSeriesPointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DomainChartSeriesPointerEventArgsDescriptionMetadata.c(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
            }
            if (a.k(DomainChartSeriesPointerEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Series", "ExportedType:Series");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            DomainChartSeriesPointerEventArgsDescriptionMetadata.b(a);
            a.ad("DomainChartSeriesPointerEventArgs", () => new DomainChartSeriesPointerEventArgsDescription());
            a.ac("DomainChartSeriesPointerEventArgs", DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
        }
    }
    DomainChartSeriesPointerEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DomainChartSeriesPointerEventArgsDescriptionMetadata, 'DomainChartSeriesPointerEventArgsDescriptionMetadata');
    DomainChartSeriesPointerEventArgsDescriptionMetadata.a = null;
    return DomainChartSeriesPointerEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/DomainChartSeriesPointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { DomainChartSeriesPointerEventArgsDescription } from "./DomainChartSeriesPointerEventArgsDescription";
/**
 * @hidden
 */
export let DomainChartSeriesPointerEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DomainChartSeriesPointerEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DomainChartSeriesPointerEventArgsDescriptionMetadata.a == null) {
                DomainChartSeriesPointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DomainChartSeriesPointerEventArgsDescriptionMetadata.c(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
            }
            if (a.k(DomainChartSeriesPointerEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Series", "ExportedType:Series");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            DomainChartSeriesPointerEventArgsDescriptionMetadata.b(a);
            a.ae("DomainChartSeriesPointerEventArgs", () => new DomainChartSeriesPointerEventArgsDescription());
            a.ad("DomainChartSeriesPointerEventArgs", DomainChartSeriesPointerEventArgsDescriptionMetadata.a);
        }
    }
    DomainChartSeriesPointerEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DomainChartSeriesPointerEventArgsDescriptionMetadata, 'DomainChartSeriesPointerEventArgsDescriptionMetadata');
    DomainChartSeriesPointerEventArgsDescriptionMetadata.a = null;
    return DomainChartSeriesPointerEventArgsDescriptionMetadata;
})();
